#
# spec file for package python-vistir
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-vistir
Version:        0.8.0
Release:        1.6
Summary:        Utilities for filesystems, paths, projects, subprocesses, and more
License:        ISC
Group:          Development/Languages/Python
URL:            https://github.com/sarugaku/vistir
Source:         https://github.com/sarugaku/vistir/archive/refs/tags/v%{version}.tar.gz#/vistir-%{version}.tar.gz
BuildRequires:  %{python_module setuptools >= 40.8.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-colorama >= 0.3.4
Recommends:     python-requests
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module colorama >= 0.3.4}
BuildRequires:  %{python_module hypothesis-fspaths}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
# /SECTION
%python_subpackages

%description
Miscellaneous utilities for dealing with filesystems, paths, projects,
subprocesses, and more.

%prep
%setup -q -n vistir-%{version}

sed -i '/invoke/d;/parver/d;/wheel$/d;/addopts/d' setup.cfg

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8

# test_open_file_without_requests requires network access
# test_path_to_url needs bigger seed than some of our virtuals provide
# test_ensure_mkdir_p race condition
# test_mkdir_p very slow on Leap Python 2
# test_decode_encode and test_run_failing_subprocess fails on Leap 15.2 Python 2
%{python_expand skip_tests="test_open_file_without_requests"
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -m pytest -v -k "not ($skip_tests)"
}

%files %{python_files}
%doc CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue May  9 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Drop spinner
  * Drop deprecated functions
  * Drop ability to import all from the package, instead user
    from vistir.<module>.
* Fri Oct 14 2022 pgajdos@suse.com
- version update to 0.7.0
  - Drop backports modules ``vistir.compat``
  - Bug fix
  - Remove Python2 support
  - Fix bug where ``rmtree`` fails in non ``utf-8`` system.  `#116 <https://github.com/sarugaku/vistir/issues/116>`_
  - * Remove unsupported test runners for Python 2.7, 3.5 and 3.6
  * Add test runner for Python 3.9
  * remove reference to distutils
  * Update ``vistir`` Pipfile.lock after pinning ``pytest`` to prior working version
  * Remove ``pytype`` from the lock file as it was faiing to install
  * Remove ``coveralls`` from the CI
  * Remove Azure pipelines  `#130 <https://github.com/sarugaku/vistir/issues/130>`_
* Mon Feb 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Skip building on python2 (this doesn't work anymore)
* Fri Nov 13 2020 John Vandenberg <jayvdb@gmail.com>
- Disable tests that fail on Python 2 only, fixing Leap builds
* Wed Jul 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.5.2
  * small fixes
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.5.0
  * Reimplemented vistir.contextmanagers.open_file to fall back to
    urllib.urlopen in the absence of requests, which is now an optional extra.
  * Fixed a bug which caused path_to_url to sometimes fail to properly
    encode surrogates using utf-8 on windows using python 3.
- drop upstreamed patch fix-test_Account-for-encoded-length.patch
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Conditionalize python2 build to do it only on older codestreams
* Thu Jan  2 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix test case failing due to too long generated name:
  * Add fix-test_Account-for-encoded-length.patch
* Wed Dec  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip additional tests as they requires bigger seed than most
  of OBS machines are providing
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.3:
  * Added compatibility shim for TimeoutError exception handling. #92
  * Exceptions are no longer suppressed after being handled during vistir.misc.run. #95
  * The signal handler for VistirSpinner will no longer cause deadlocks when CTRL_BREAK_EVENTS occur on windows. #96
* Fri May 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.2:
  * Added expanded functionality to assist with the removal of read-only
    paths on Windows via icacls system calls if necessary. #81
  * Improved fs_encode compatibility shim in vistir.compat for
    handling of non-UTF8 data. #83
  * Shortened windows paths will now be properly resolved to the full
    path by vistir.path.normalize_path. #90
* Mon May  6 2019 pgajdos@suse.com
- version update to 0.4.0
- Fixed a bug which caused test failures due to generated paths on
  * nix based operating systems which were too long.
  `#65 <https://github.com/sarugaku/vistir/issues/65>`_
- Fixed a bug which caused spinner output to sometimes attempt to
  double encode on python 2, resulting in failed output encoding.
  `#69 <https://github.com/sarugaku/vistir/issues/69>`_
- Fixed an issue where paths could sometimes fail to be fs-encoded
  properly when using backported ``NamedTemporaryFile`` instances.
  `#74 <https://github.com/sarugaku/vistir/issues/74>`_
- Fixed a bug in ``vistir.misc.locale_encoding`` which caused
  invocation of a non-existent method called ``getlocaleencoding``
  which forced all systems to use default encoding of ``ascii``.
  `#78 <https://github.com/sarugaku/vistir/issues/78>`_
- deleted patches
  - merged_pr_68-colorama-pin.patch (upstreamed)
  - merged_pr_75-backport-pins.patch (upstreamed)
  - no-ffi.patch (upstreamed)
  - py27-missing-exception.patch (upstreamed)
* Tue Apr  2 2019 John Vandenberg <jayvdb@gmail.com>
- Add merged_pr_68-colorama-pin.patch to fix colorama minimum dependency
- Replace fix-py3-backports.patch with merged_pr_75-backport-pins.patch
- Rename GitHub tarball to match PyPI tarball name
* Fri Mar  8 2019 John Vandenberg <jayvdb@gmail.com>
- Add py27-missing-exception.patch to workaround bug in Python 2
- Fix py2 only dependencies with fix-py3-backports.patch
- Set minimum version of colorama to avoid failures on Leap standard
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball as the archive present didn't match
  the pypi archive
* Fri Mar  1 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.3.1
